@@ -17,10 +17,10 @@ from functools import reduce
 from typing import Type, Union
 
 import tensorflow as tf
+from check_shapes import check_shapes
 
 from .. import kernels
 from .. import mean_functions as mfn
-from ..experimental.check_shapes import check_shapes
 from ..inducing_variables import InducingPoints
 from ..probability_distributions import DiagonalGaussian, Gaussian, MarkovGaussian
 from . import dispatch
