@@ -24,6 +24,7 @@ tf.random.set_seed(99012)
 class Data:
     rng = np.random.RandomState(123)
     N = 5
+    X = np.linspace(0, 1, num=N)[:, None]
     Y = rng.randn(N, 1)
     f_mean = rng.randn(N, 2)
     f_var: AnyNDArray = rng.randn(N, 2) ** 2
@@ -40,7 +41,7 @@ def test_analytic_mean_and_var() -> None:
     analytic_variance = np.exp(Data.f_mean[:, [1]] + Data.f_var[:, [1]]) ** 2 + Data.f_var[:, [0]]
 
     likelihood = HeteroskedasticTFPConditional()
-    y_mean, y_var = likelihood.predict_mean_and_var(Data.f_mean, Data.f_var)
+    y_mean, y_var = likelihood.predict_mean_and_var(Data.X, Data.f_mean, Data.f_var)
 
     np.testing.assert_allclose(y_mean, analytic_mean)
     np.testing.assert_allclose(y_var, analytic_variance, rtol=1.5e-6)
